#[repr(transparent)]pub struct Miscctrl(pub u32);Expand description
Dummy Control bus to PMU [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]
Tuple Fields
0: u32Implementations
Sourceimpl Miscctrl
impl Miscctrl
Sourcepub const fn ldodeepsleepref(&self) -> Ldodeepsleepref
pub const fn ldodeepsleepref(&self) -> Ldodeepsleepref
Select LDO Deep Sleep reference source.
Sourcepub const fn set_ldodeepsleepref(&mut self, val: Ldodeepsleepref)
pub const fn set_ldodeepsleepref(&mut self, val: Ldodeepsleepref)
Select LDO Deep Sleep reference source.
Sourcepub const fn ldomemhighzmode(&self) -> bool
pub const fn ldomemhighzmode(&self) -> bool
Control the activation of LDO MEM High Z mode.
Sourcepub const fn set_ldomemhighzmode(&mut self, val: bool)
pub const fn set_ldomemhighzmode(&mut self, val: bool)
Control the activation of LDO MEM High Z mode.
Sourcepub const fn lowpwr_flash_buf(&self) -> bool
pub const fn lowpwr_flash_buf(&self) -> bool
no description available
Sourcepub const fn set_lowpwr_flash_buf(&mut self, val: bool)
pub const fn set_lowpwr_flash_buf(&mut self, val: bool)
no description available
Sourcepub const fn miscctrl_3_11(&self) -> u16
pub const fn miscctrl_3_11(&self) -> u16
Reserved.
Sourcepub const fn set_miscctrl_3_11(&mut self, val: u16)
pub const fn set_miscctrl_3_11(&mut self, val: u16)
Reserved.
Sourcepub const fn disable_bleed(&self) -> DisableBleed
pub const fn disable_bleed(&self) -> DisableBleed
Controls LDO MEM bleed current. This field is expected to be controlled by the Low Power Software only in DEEP SLEEP low power mode.
Sourcepub const fn set_disable_bleed(&mut self, val: DisableBleed)
pub const fn set_disable_bleed(&mut self, val: DisableBleed)
Controls LDO MEM bleed current. This field is expected to be controlled by the Low Power Software only in DEEP SLEEP low power mode.
Sourcepub const fn miscctrl_13_15(&self) -> u8
pub const fn miscctrl_13_15(&self) -> u8
Reserved.
Sourcepub const fn set_miscctrl_13_15(&mut self, val: u8)
pub const fn set_miscctrl_13_15(&mut self, val: u8)
Reserved.