nxp-pac

Crates

git

Versions

lpc55s16

Flavors

Wakeupioctrl

Struct Wakeupioctrl 

#[repr(transparent)]
pub struct Wakeupioctrl(pub u32);
Deep Power Down wake-up source [Reset by: PoR, Pin Reset, Software Reset]

Tuple Fields

0: u32

Implementations

Source

impl Wakeupioctrl

pub const fn risingedgewakeup0(&self) -> bool

Enable / disable detection of rising edge events on Wake Up 0 pin in Deep Power Down modes:.

pub const fn set_risingedgewakeup0(&mut self, val: bool)

Enable / disable detection of rising edge events on Wake Up 0 pin in Deep Power Down modes:.

pub const fn fallingedgewakeup0(&self) -> bool

Enable / disable detection of falling edge events on Wake Up 0 pin in Deep Power Down modes:.

pub const fn set_fallingedgewakeup0(&mut self, val: bool)

Enable / disable detection of falling edge events on Wake Up 0 pin in Deep Power Down modes:.

pub const fn risingedgewakeup1(&self) -> bool

Enable / disable detection of rising edge events on Wake Up 1 pin in Deep Power Down modes:.

pub const fn set_risingedgewakeup1(&mut self, val: bool)

Enable / disable detection of rising edge events on Wake Up 1 pin in Deep Power Down modes:.

pub const fn fallingedgewakeup1(&self) -> bool

Enable / disable detection of falling edge events on Wake Up 1 pin in Deep Power Down modes:.

pub const fn set_fallingedgewakeup1(&mut self, val: bool)

Enable / disable detection of falling edge events on Wake Up 1 pin in Deep Power Down modes:.

pub const fn risingedgewakeup2(&self) -> bool

Enable / disable detection of rising edge events on Wake Up 2 pin in Deep Power Down modes:.

pub const fn set_risingedgewakeup2(&mut self, val: bool)

Enable / disable detection of rising edge events on Wake Up 2 pin in Deep Power Down modes:.

pub const fn fallingedgewakeup2(&self) -> bool

Enable / disable detection of falling edge events on Wake Up 2 pin in Deep Power Down modes:.

pub const fn set_fallingedgewakeup2(&mut self, val: bool)

Enable / disable detection of falling edge events on Wake Up 2 pin in Deep Power Down modes:.

pub const fn risingedgewakeup3(&self) -> bool

Enable / disable detection of rising edge events on Wake Up 3 pin in Deep Power Down modes:.

pub const fn set_risingedgewakeup3(&mut self, val: bool)

Enable / disable detection of rising edge events on Wake Up 3 pin in Deep Power Down modes:.

pub const fn fallingedgewakeup3(&self) -> bool

Enable / disable detection of falling edge events on Wake Up 3 pin in Deep Power Down modes:.

pub const fn set_fallingedgewakeup3(&mut self, val: bool)

Enable / disable detection of falling edge events on Wake Up 3 pin in Deep Power Down modes:.

pub const fn modewakeupiopad0(&self) -> Modewakeupiopad0

Selects function mode (on-chip pull-up/pull-down resistor control).

pub const fn set_modewakeupiopad0(&mut self, val: Modewakeupiopad0)

Selects function mode (on-chip pull-up/pull-down resistor control).

pub const fn modewakeupiopad1(&self) -> Modewakeupiopad1

Selects function mode (on-chip pull-up/pull-down resistor control).

pub const fn set_modewakeupiopad1(&mut self, val: Modewakeupiopad1)

Selects function mode (on-chip pull-up/pull-down resistor control).

pub const fn modewakeupiopad2(&self) -> Modewakeupiopad2

Selects function mode (on-chip pull-up/pull-down resistor control).

pub const fn set_modewakeupiopad2(&mut self, val: Modewakeupiopad2)

Selects function mode (on-chip pull-up/pull-down resistor control).

pub const fn modewakeupiopad3(&self) -> Modewakeupiopad3

Selects function mode (on-chip pull-up/pull-down resistor control).

pub const fn set_modewakeupiopad3(&mut self, val: Modewakeupiopad3)

Selects function mode (on-chip pull-up/pull-down resistor control).

pub const fn wakeupio_enable_ctrl(&self) -> bool

Enable WAKEUP IO PAD control from MODEWAKEUPIOPAD (bits 12 to 19).

pub const fn set_wakeupio_enable_ctrl(&mut self, val: bool)

Enable WAKEUP IO PAD control from MODEWAKEUPIOPAD (bits 12 to 19).

pub const fn wakeupio_rstn(&self) -> WakeupioRstn

WAKEUP IO event detector reset control.

pub const fn set_wakeupio_rstn(&mut self, val: WakeupioRstn)

WAKEUP IO event detector reset control.